@@ -1,8 +1,8 @@
 from __future__ import unicode_literals
 
 
-__author__ = 'Dmitriy Sokolov'
-__version__ = '0.2'
+__author__ = 'Michele Matera'
+__version__ = '0.5'
 
 
 default_app_config = 'djangodaylessdate.apps.DjangoDaylessDateConfig'
